
# This file is automatically generated, you probably don't want to edit this

anovaNPOptions <- if (requireNamespace('jmvcore')) R6::R6Class(
    "anovaNPOptions",
    inherit = jmvcore::Options,
    public = list(
        initialize = function(
            deps = NULL,
            group = NULL,
            pairs = FALSE, ...) {

            super$initialize(
                package='jmv',
                name='anovaNP',
                requiresData=TRUE,
                ...)

            private$..deps <- jmvcore::OptionVariables$new(
                "deps",
                deps,
                required=TRUE,
                suggested=list(
                    "continuous"),
                permitted=list(
                    "numeric"))
            private$..group <- jmvcore::OptionVariable$new(
                "group",
                group,
                required=TRUE,
                rejectUnusedLevels=TRUE,
                suggested=list(
                    "nominal",
                    "ordinal"),
                permitted=list(
                    "factor"))
            private$..pairs <- jmvcore::OptionBool$new(
                "pairs",
                pairs,
                default=FALSE)

            self$.addOption(private$..deps)
            self$.addOption(private$..group)
            self$.addOption(private$..pairs)
        }),
    active = list(
        deps = function() private$..deps$value,
        group = function() private$..group$value,
        pairs = function() private$..pairs$value),
    private = list(
        ..deps = NA,
        ..group = NA,
        ..pairs = NA)
)

anovaNPResults <- if (requireNamespace('jmvcore')) R6::R6Class(
    inherit = jmvcore::Group,
    active = list(
        table = function() private$.items[["table"]],
        comparisons = function() private$.items[["comparisons"]]),
    private = list(),
    public=list(
        initialize=function(options) {
            super$initialize(
                options=options,
                name="",
                title="One-way ANOVA (Non-parametric)")
            self$add(jmvcore::Table$new(
                options=options,
                name="table",
                title="Kruskal-Wallis",
                rows="(deps)",
                clearWith=list(
                    "group"),
                columns=list(
                    list(
                        `name`="name", 
                        `title`="", 
                        `content`="($key)", 
                        `type`="text"),
                    list(
                        `name`="chiSq", 
                        `title`="\u03C7\u00B2", 
                        `type`="number"),
                    list(
                        `name`="df", 
                        `title`="df", 
                        `type`="integer"),
                    list(
                        `name`="p", 
                        `title`="p", 
                        `type`="number", 
                        `format`="zto,pvalue"))))
            self$add(jmvcore::Array$new(
                options=options,
                name="comparisons",
                title="Dwass-Steel-Critchlow-Fligner pairwise comparisons",
                items="(deps)",
                visible="(pairs)",
                clearWith=list(
                    "group"),
                template=jmvcore::Table$new(
                    options=options,
                    title="Pairwise comparisons - $key",
                    rows=0,
                    clearWith=NULL,
                    columns=list(
                        list(
                            `name`="p1", 
                            `title`="", 
                            `content`=".", 
                            `type`="text"),
                        list(
                            `name`="p2", 
                            `title`="", 
                            `content`=".", 
                            `type`="text"),
                        list(
                            `name`="W", 
                            `type`="number"),
                        list(
                            `name`="p", 
                            `title`="p", 
                            `type`="number", 
                            `format`="zto,pvalue")))))}))

anovaNPBase <- if (requireNamespace('jmvcore')) R6::R6Class(
    "anovaNPBase",
    inherit = jmvcore::Analysis,
    public = list(
        initialize = function(options, data=NULL, datasetId="", analysisId="", revision=0) {
            super$initialize(
                package = 'jmv',
                name = 'anovaNP',
                version = c(1,0,0),
                options = options,
                results = anovaNPResults$new(options=options),
                data = data,
                datasetId = datasetId,
                analysisId = analysisId,
                revision = revision,
                pause = NULL,
                completeWhenFilled = TRUE)
        }))

#' One Way ANOVA (Non-parametric)
#'
#' Kruskal-Wallis
#'
#' @examples
#' data('ToothGrowth')
#'
#' anovaNP(ToothGrowth, deps = 'len', group = 'dose')
#'
#' #
#' #  ONE-WAY ANOVA (NON-PARAMETRIC)
#' #
#' #  Kruskal-Wallis
#' #  -------------------------------
#' #           X²      df    p
#' #  -------------------------------
#' #    len    40.7     2    < .001
#' #  -------------------------------
#' #
#'
#' @param data the data as a data frame
#' @param deps a string naming the dependent variable in \code{data}
#' @param group a string naming the grouping or independent variable in
#'   \code{data}
#' @param pairs \code{TRUE} or \code{FALSE} (default), perform pairwise
#'   comparisons
#' @return A results object containing:
#' \tabular{llllll}{
#'   \code{results$table} \tab \tab \tab \tab \tab a table of the test results \cr
#'   \code{results$comparisons} \tab \tab \tab \tab \tab an array of pairwise comparison tables \cr
#' }
#'
#' Tables can be converted to data frames with \code{asDF} or \code{\link{as.data.frame}}. For example:
#'
#' \code{results$table$asDF}
#'
#' \code{as.data.frame(results$table)}
#'
#' @export
anovaNP <- function(
    data,
    deps,
    group,
    pairs = FALSE) {

    if ( ! requireNamespace('jmvcore'))
        stop('anovaNP requires jmvcore to be installed (restart may be required)')

    if (missing(data))
        data <- jmvcore:::marshalData(
            parent.frame(),
            `if`( ! missing(deps), deps, NULL),
            `if`( ! missing(group), group, NULL))

    options <- anovaNPOptions$new(
        deps = deps,
        group = group,
        pairs = pairs)

    results <- anovaNPResults$new(
        options = options)

    analysis <- anovaNPClass$new(
        options = options,
        data = data)

    analysis$run()

    analysis$results
}
